pub trait IntoMoveArg {
// Required method
fn into_move_arg(self) -> AptosResult<Vec<u8>>;
}Expand description
Trait for types that can be converted to entry function arguments.
This trait is automatically implemented for types that implement Serialize.
Required Methods
Sourcefn into_move_arg(self) -> AptosResult<Vec<u8>>
fn into_move_arg(self) -> AptosResult<Vec<u8>>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".