IntoMoveArg

Trait IntoMoveArg 

pub trait IntoMoveArg {
    // Required method
    fn into_move_arg(self) -> AptosResult<Vec<u8>>;
}
Trait for types that can be converted to entry function arguments.

This trait is automatically implemented for types that implement Serialize.

Required Methods

fn into_move_arg(self) -> AptosResult<Vec<u8>>

Converts this value into BCS-encoded bytes.

Errors

Returns an error if BCS serialization fails.

Implementors