pub trait IntoMoveArg {
// Required method
fn into_move_arg(self) -> AptosResult<Vec<u8>>;
}Expand description
Trait for types that can be converted to entry function arguments.
This trait is automatically implemented for types that implement Serialize.